@@ -37,6 +37,9 @@ Options:
   --num-cores, --num_cores INTEGER
                                   Number of CPU cores to run deepsparse with,
                                   default is all available
+  --dataset-kwargs, --dataset_kwargs TEXT
+                                  Keyword arguments to be passed to dataset
+                                  constructor, should be specified as a json
   --help                          Show this message and exit.
 
 #########
@@ -49,6 +52,9 @@ python validation_script.py \
   --dataset-path /path/to/imagenette/
 
 """
+import json
+from typing import Dict
+
 import click
 import torchvision
 from torchvision import transforms
@@ -67,6 +73,20 @@ resnet50_imagenet_pruned = (
 )
 
 
+def parse_json_callback(ctx, params, value: str) -> Dict:
+    """
+    Parse a json string into a dictionary
+    :param ctx: The click context
+    :param params: The click params
+    :param value: The json string to parse
+    :return: The parsed dictionary
+    """
+    # JSON string -> dict Callback
+    if isinstance(value, str):
+        return json.loads(value)
+    return value
+
+
 @click.command()
 @click.option(
     "--dataset-path",
@@ -109,18 +129,49 @@ resnet50_imagenet_pruned = (
     show_default=True,
     help="Number of CPU cores to run deepsparse with, default is all available",
 )
+@click.option(
+    "--dataset-kwargs",
+    "--dataset_kwargs",
+    default=json.dumps({}),
+    type=str,
+    callback=parse_json_callback,
+    help="Keyword arguments to be passed to dataset constructor, "
+    "should be specified as a json object",
+)
 def main(
-    dataset_path: str, model_path: str, batch_size: int, image_size: int, num_cores: int
+    dataset_path: str,
+    model_path: str,
+    batch_size: int,
+    image_size: int,
+    num_cores: int,
+    dataset_kwargs: Dict,
 ):
     """
     Validation Script for Image Classification Models
     """
-    non_rand_resize_scale = 256.0 / 224.0  # standard used
+
+    if "resize_scale" in dataset_kwargs:
+        resize_scale = dataset_kwargs["resize_scale"]
+    else:
+        resize_scale = 256.0 / 224.0  # standard used
+
+    if "resize_mode" in dataset_kwargs:
+        resize_mode = dataset_kwargs["resize_mode"]
+    else:
+        resize_mode = "bilinear"
+
+    if type(resize_mode) is str and resize_mode.lower() in ["linear", "bilinear"]:
+        interpolation = transforms.InterpolationMode.BILINEAR
+    elif type(resize_mode) is str and resize_mode.lower() in ["cubic", "bicubic"]:
+        interpolation = transforms.InterpolationMode.BICUBIC
+
     dataset = torchvision.datasets.ImageFolder(
         root=dataset_path,
         transform=transforms.Compose(
             [
-                transforms.Resize(round(non_rand_resize_scale * image_size)),
+                transforms.Resize(
+                    round(resize_scale * image_size), interpolation=interpolation
+                ),
                 transforms.CenterCrop(image_size),
                 transforms.ToTensor(),
                 transforms.Normalize(mean=IMAGENET_RGB_MEANS, std=IMAGENET_RGB_STDS),
@@ -152,6 +203,8 @@ def main(
 
         for actual, predicted in zip(actual_labels, predicted_labels):
             total += 1
+            if isinstance(predicted, list):
+                predicted = predicted[0]  # unwrap label returned as list
             if isinstance(predicted, str):
                 predicted = int(predicted)
             if actual.item() == predicted:
